/**
 * 销售单详情
 */
import { ElTag } from "element-plus";
import { h } from "vue";
import { createTooltip } from "../tootip";
import { SEND_TYPE } from "./purchase";
import { DescriptionColumns } from "/@/components/BasicDescriptions";

export const SALE_STATUS = [
  {
    value: "0",
    label: "未核销"
  },
  {
    value: "1",
    label: "核销中"
  },
  {
    value: "2",
    label: "不参与核销"
  }
];

export const SALE_GOOD_TYPE = [
  {
    value: "1",
    label: "正常商品"
  },
  {
    value: "2",
    label: "赠品"
  },
  {
    value: "3",
    label: "样品"
  }
];

const PAY_STATUS = [
  {
    value: "1",
    label: "未回款"
  },
  {
    value: "2",
    label: "部分回款"
  },
  {
    value: "3",
    label: "已回款"
  }
];

const INV_STATUS = [
  {
    value: "1",
    label: "未开票"
  },
  {
    value: "2",
    label: "部分开票"
  },
  {
    value: "3",
    label: "已开票"
  }
];

export const ORDER_COLUMNS: DescriptionColumns = [
  {
    field: "sequenceNo",
    label: "销售单编号",
    labelWidth: "80px",
    span: 2
  },
  {
    field: "ownerName",
    labelWidth: "80px",
    span: 2,
    label: "销售员",
    render: (ownerName, { ownerid }) =>
      createTooltip(ownerName, "销售员id : " + ownerid, 160)
  },
  {
    field: "createdTime",
    labelWidth: "80px",
    span: 1,
    label: "新建时间"
  },
  {
    field: "department",
    labelWidth: "80px",
    span: 1,
    label: "销售部门"
  },
  {
    field: "companyName",
    label: "业务公司",
    span: 3,
    render: (company, { companyNo }) =>
      createTooltip(company, "业务公司编号 : " + companyNo, 270)
  },
  {
    field: "customerName",
    label: "客户公司",
    span: 3,
    render: (customer, { customerNo }) =>
      createTooltip(customer, "客户公司编号 : " + customerNo, 270)
  },
  {
    field: "poCode",
    span: 2,
    label: "po编号"
  },
  {
    field: "cgdNo",
    span: 2,
    label: "采购单号"
  },
  {
    field: "status",
    label: "状态",
    span: 1,
    render(data) {
      return h(ElTag, null, {
        default: () => SALE_STATUS.find(s => s.value === data)?.label
      });
    }
  },
  {
    field: "platName",
    span: 1,
    label: "平台名称"
  },
  {
    field: "wsendNum",
    label: "未发货"
  },
  {
    field: "sendNum",
    label: "已发货"
  },
  {
    field: "pay_fee",
    label: "付款中"
  },
  {
    field: "apay_fee",
    label: "已付款"
  },
  {
    field: "inv_fee",
    label: "开票中"
  },
  {
    field: "ainv_fee",
    label: "已开票"
  },
  {
    field: "sendType",
    label: "发货方式",
    render(data) {
      return h(ElTag, null, {
        default: () => SEND_TYPE.find(t => t.value === data)?.label
      });
    }
  },
  {
    field: "inv_status",
    label: "开票状态",
    render(data) {
      return h(ElTag, null, {
        default: () => INV_STATUS.find(t => t.value === data)?.label
      });
    }
  },
  {
    field: "pay_status",
    label: "付款状态",
    render(data) {
      return h(ElTag, null, {
        default: () => PAY_STATUS.find(t => t.value === data)?.label
      });
    }
  },
  {
    field: "thNum",
    label: "退货数量"
  },
  {
    field: "th_fee",
    label: "退货金额"
  },
  {
    field: "diff_weight",
    label: "工差重量"
  },
  {
    field: "diff_fee",
    label: "工差金额"
  },
  {
    field: "customerAttr",
    label: "公司属性"
  },
  {
    field: "branch",
    label: "分公司"
  },
  {
    field: "paytime",
    label: "付款时间"
  }
];

export const GOOD_COLUMNS: DescriptionColumns = [
  {
    field: "goodNo",
    label: "商品编号",
    span: 2
  },
  {
    field: "goodBrand",
    label: "品牌"
  },
  {
    field: "firstCat",
    label: "一级分类"
  },
  {
    field: "secCat",
    label: "二级分类"
  },
  {
    field: "thirdCat",
    label: "三级分类"
  },
  {
    field: "goodMaterial",
    label: "材质"
  },
  {
    field: "goodType",
    label: "商品类型",
    render(data) {
      return h(ElTag, null, {
        default: () => SALE_GOOD_TYPE.find(t => t.value === data)?.label
      });
    }
  },
  {
    field: "isStock",
    label: "是否库存",
    render(data) {
      return h(ElTag, null, {
        default: () => (data === "1" ? "库存" : "非库存")
      });
    }
  },
  {
    field: "goodModel",
    label: "型号"
  },
  {
    field: "metalsType",
    label: "贵金属种类"
  },
  {
    field: "weight",
    label: "重量"
  },
  {
    field: "goldPrice",
    label: "金价"
  },
  {
    field: "workDay",
    label: "工期"
  },
  {
    field: "tax",
    label: "税率"
  },
  {
    field: "goodNum",
    label: "商品数量"
  },
  {
    field: "goodPrice",
    label: "商品单价"
  },
  {
    field: "totalPrice",
    label: "总金额"
  }
];

export const SALE_COLUMNS: DescriptionColumns = [
  ...ORDER_COLUMNS,
  ...GOOD_COLUMNS
];
