import { h } from "vue";
import { ElTag } from "element-plus";
import { createTooltip } from "/@/utils/tootip";
import { DescriptionColumns } from "/@/components/BasicDescriptions";
import {
  redReasonOptions,
  returnTypeOptions,
  openTypeOptions,
  returnStatusOptions
} from "./_options";

export const invReturnColumns: DescriptionColumns = [
  {
    field: "returnCode",
    label: "退票编号",
    span: 2
  },
  {
    field: "invNo",
    label: "开票申请编号",
    span: 2
  },
  {
    field: "post_code",
    label: "物流编号",
    span: 2
  },
  {
    field: "red_inv",
    span: 2,
    label: "红冲发票信息"
  },
  {
    field: "return_reason",
    label: "红冲原因",
    span: 1,
    render(data) {
      return h(ElTag, null, {
        default: () =>
          redReasonOptions.find(t => t.value === String(data))?.label || "--"
      });
    }
  },
  {
    field: "return_type",
    label: "退票方式",
    render(data) {
      return h(ElTag, null, {
        default: () =>
          returnTypeOptions.find(t => t.value === String(data))?.label || "--"
      });
    }
  },
  {
    field: "open_type",
    label: "开票类型",
    span: 2,
    render(data) {
      return h(ElTag, null, {
        default: () =>
          openTypeOptions.find(t => t.value === String(data))?.label || "--"
      });
    }
  },
  {
    field: "apply_name",
    span: 2,
    label: "申请人",
    render: (apply_name, { apply_id }) =>
      createTooltip(apply_name, "申请人ID : " + apply_id, 160)
  },
  {
    field: "status",
    label: "退票状态",
    render(data) {
      return h(ElTag, null, {
        default: () =>
          returnStatusOptions.find(t => t.value === String(data))?.label || "--"
      });
    }
  },
  {
    field: "seller_title",
    label: "开票业务公司",
    render: (seller_title, { inv_out }) =>
      createTooltip(seller_title, "业务公司编号 : " + inv_out, 280)
  },
  {
    field: "buyer_title",
    label: "客户公司"
  },
  {
    field: "inv_value",
    span: 2,
    label: "发票总额"
  },
  {
    field: "email",
    label: "电子邮箱"
  },
  {
    field: "remark",
    label: "备注"
  }
];

export const inv_columns = [
  {
    label: "发票申请编号",
    prop: "invNo",
    width: 150
  },
  {
    label: "业务公司编码",
    prop: "inv_out",
    width: 160
  },
  {
    label: "业务公司名称",
    prop: "inv_company",
    width: 140
  },
  {
    label: "发票号码",
    prop: "inv_code",
    width: 110
  },
  {
    label: "发票代码",
    prop: "inv_number",
    width: 110
  },
  {
    label: "发票额度",
    prop: "inv_value",
    width: 110
  },
  {
    label: "申请人",
    prop: "apply_name",
    width: 80
  },
  {
    label: "开票日期",
    width: 145,
    prop: "open_date"
  },
  {
    label: "创建时间",
    width: 145,
    prop: "addtime"
  }
];
