import { ContentConfig } from "/@/components/PageContent";
import { httpList } from "/@/api/InvoiceSales/sheetOrderPool";

import { h } from "vue";
import { ElImage, ElTag } from "element-plus";
import { send_status_list } from "/@/utils/status";

import {
  cat_status,
  good_source,
  good_type,
  inv_open_status,
  retrun_status
} from "./search.config";

const columns = [
  {
    type: "selection",
    width: 55,
    hide: ({ checkList }) => !checkList.includes("勾选列")
  },
  {
    label: "序号",
    type: "index",
    width: 70,
    hide: ({ checkList }) => !checkList.includes("序号列")
  },
  {
    label: "确认单编号",
    prop: "sequenceNo",
    width: 150
  },
  {
    label: "确认单名称",
    prop: "name",
    width: 150
  },
  {
    label: "客户编号",
    prop: "customerNo",
    width: 100
  },
  {
    label: "客户名称",
    prop: "customerName",
    width: 100
  },
  {
    label: "部门",
    prop: "department",
    width: 100
  },
  {
    label: "平台名称",
    prop: "platName",
    width: 100
  },
  {
    label: "商品类型",
    width: 100,
    cellRenderer: ({ row }) =>
      h(ElTag, null, {
        default: () =>
          good_type.find(s => s.value === row.qrdType)?.label || "--"
      })
  },
  {
    label: "发货状态",
    width: 100,
    cellRenderer: ({ row }) =>
      h(ElTag, null, {
        default: () =>
          send_status_list.find(s => s.value === row.sendStatus)?.label || "--"
      })
  },
  {
    label: "订单来源",
    width: 100,
    cellRenderer: ({ row }) =>
      h(ElTag, null, {
        default: () =>
          good_source.find(s => s.value === row.qrdSource)?.label || "--"
      })
  },
  {
    label: "开票状态",
    width: 100,
    cellRenderer: ({ row }) =>
      h(ElTag, null, {
        default: () =>
          inv_open_status.find(s => s.value === row.inv_status)?.label || "--"
      })
  },
  {
    label: "已开票",
    prop: "ainv_fee"
  },
  {
    label: "开票中",
    prop: "inv_fee"
  },
  {
    label: "开票标签金额",
    prop: "inv_tag_fee",
    width: 120
  },
  {
    label: "开票标签图片",
    width: "120px",
    cellRenderer({ row }) {
      if (!row.inv_tag_img) return null;

      return h(ElImage, {
        src: row.inv_tag_img,
        previewSrcList: [row.inv_tag_img],
        previewTeleported: true,
        style: {
          height: "20px",
          width: "20px"
        }
      });
    }
  },
  {
    label: "未开票",
    prop: "winv_fee",
    width: 100
  },
  {
    label: "回款状态",
    width: 110,
    cellRenderer: ({ row }) => {
      return h(ElTag, null, {
        default: () =>
          retrun_status.find(s => s.value === row.pay_status)?.label
      });
    }
  },
  {
    label: "已回款",
    prop: "apay_fee",
    width: 100
  },
  {
    label: "回款中",
    prop: "pay_fee"
  },
  {
    label: "回款标签金额",
    prop: "pay_tag_fee",
    width: 120
  },
  {
    label: "回款标签图片",
    width: "120px",
    cellRenderer({ row }) {
      if (!row.pay_tag_img) return null;

      return h(ElImage, {
        src: row.pay_tag_img,
        previewSrcList: [row.pay_tag_img],
        previewTeleported: true,
        style: {
          height: "20px",
          width: "20px"
        }
      });
    }
  },
  {
    label: "未回款",
    prop: "wpay_fee"
  },
  {
    label: "销售员",
    prop: "ownerName"
  },
  {
    label: "操作",
    fixed: "right",
    width: 120,
    slot: "operation"
  }
];

const contentConfig: ContentConfig = {
  title: "确认单公海池",
  columns,
  superUserNoAction: true,
  payProps: {
    prop: "sequenceNo",
    type: "3"
  },
  returnProps: {
    prop: "sequenceNo",
    type: "4"
  },
  apis: {
    httpList
  }
};

export default contentConfig;
