import { httpList, httpDel } from "/@/api/purchase/orderRecord";

import dayjs from "dayjs";
import { statusOptions } from "./_options";
import { ContentConfig } from "/@/components/PageContent";
import { renderProp } from "/@/utils/columnRenderHelper";

const columns = [
  {
    type: "selection",
    minWidth: 55,
    align: "left",
    hide: ({ checkList }) => !checkList.includes("勾选列")
  },
  {
    label: "序号",
    type: "index",
    minWidth: 60,
    align: "left",
    hide: ({ checkList }) => !checkList.includes("序号列")
  },
  {
    label: "对账编号",
    prop: "payNo",
    minWidth: 180,
    align: "left"
  },
  {
    label: "状态",
    prop: "status",
    minWidth: 120,
    transform: status =>
      statusOptions.find(s => status === s.value)?.label || "--",
    ...renderProp(statusOptions)
  },
  {
    label: "总额款",
    prop: "total_fee",
    minWidth: 110,
    align: "total_fee"
  },
  {
    label: "卖方公司编号",
    prop: "supplierNo",
    minWidth: 180,
    align: "left"
  },
  {
    label: "卖方公司名称",
    prop: "supplierName",
    minWidth: 180,
    align: "left"
  },
  {
    label: "买方公司编号",
    prop: "companyNo",
    minWidth: 180,
    align: "left"
  },
  {
    label: "买方公司名称",
    prop: "companyName",
    minWidth: 180,
    align: "left"
  },
  {
    label: "申请人",
    prop: "apply_name",
    minWidth: 70,
    align: "left"
  },
  {
    label: "申请时间",
    minWidth: 180,
    prop: "addtime",
    formatter: ({ addtime }) => dayjs(addtime).format("YYYY-MM-DD HH:mm:ss")
  },
  {
    label: "操作",
    fixed: "right",
    width: 120,
    slot: "operation"
  }
];

const contentConfig: ContentConfig = {
  title: "订单对账",
  columns,
  apis: {
    httpList,
    httpDelete: httpDel
  },
  superUserNoAction: true,
  showDelete: () => false
};

export default contentConfig;
