import { ContentConfig } from "/@/components/PageContent";
import { httpList, httpDelete } from "/@/api/purchase/ticketReturn";

import dayjs from "dayjs";
import { h } from "vue";
import { ElImage, ElTag } from "element-plus";
import { checkTypeOptions, invTypeOptions, statusOptions } from "./_opitons";

const columns = [
  {
    type: "selection",
    width: 55,
    hide: ({ checkList }) => !checkList.includes("勾选列")
  },
  {
    label: "序号",
    type: "index",
    width: 70,
    hide: ({ checkList }) => !checkList.includes("序号列")
  },
  {
    label: "对账回票申请",
    prop: "hpNo",
    width: 180
  },
  {
    label: "对账编号",
    prop: "payNo",
    width: 180
  },
  {
    label: "状态",
    prop: "status",
    width: 160,
    transform: status =>
      statusOptions.find(s => String(status) === String(s.value))?.label,
    cellRenderer: ({ row, props }) =>
      h(
        ElTag,
        {
          size: props.size
        },
        {
          default: () =>
            statusOptions.find(s => String(row.status) === String(s.value))
              ?.label
        }
      )
  },
  {
    label: "发票上传方式",
    prop: "invType",
    width: 120,
    cellRenderer: ({ row, props }) =>
      h(
        ElTag,
        {
          size: props.size
        },
        {
          default: () =>
            invTypeOptions.find(s => String(row.invType) === String(s.value))
              ?.label
        }
      )
  },
  {
    label: "发票查验方式",
    width: 120,
    cellRenderer: ({ row, props }) =>
      h(
        ElTag,
        {
          size: props.size
        },
        {
          default: () =>
            checkTypeOptions.find(s => String(row.checkApi) === s.value)?.label
        }
      )
  },
  {
    label: "发票图片",
    prop: "inv_img",
    width: 85,
    cellRenderer: ({ row }) =>
      h(ElImage, {
        src: row.inv_img,
        style: { height: "20px" },
        previewSrcList: [row.inv_img],
        previewTeleported: true
      })
  },
  {
    label: "发票税前金额",
    width: "110px",
    prop: "inv_subtotal_amount"
  },
  {
    label: "发票税后金额",
    width: "110px",
    prop: "total"
  },
  {
    label: "发票号码",
    width: 110,
    prop: "invoiceNumber"
  },
  {
    label: "发票代码",
    width: 110,
    prop: "invoiceCode"
  },
  {
    label: "开票时间",
    prop: "open_time",
    width: 120,
    formatter: ({ open_time }) =>
      open_time ? dayjs(open_time).format("YYYY-MM-DD") : ""
  },
  {
    label: "发票状态",
    width: 110,
    prop: "invStatus_cn"
  },
  {
    label: "发票类型",
    width: 110,
    prop: "invoiceType_cn"
  },
  {
    label: "申请人",
    prop: "apply_name"
  },
  {
    label: "创建时间",
    prop: "addtime",
    width: 180,
    formatter: ({ addtime }) => dayjs(addtime).format("YYYY-MM-DD HH:mm:ss")
  },
  {
    label: "操作",
    fixed: "right",
    slot: "operation",
    width: 110
  }
];

const contentConfig: ContentConfig = {
  title: "采购回票",
  statusProp: "companyNo",
  columns,
  apis: {
    httpDelete,
    httpList
  },
  deleteProp: "hpNo",
  delTooltip: "是否撤回采购回票申请",
  superUserNoAction: true,
  showDelete: ({ status }) => Number(status) <= 3
};

export default contentConfig;
