import { h } from "vue";
import { ElTag } from "element-plus";
import {
  cg_order_type_options,
  cg_order_source_options,
  send_status_list
} from "/@/utils/status";
import { createTooltip } from "/@/utils/tootip";
import { DescriptionColumns } from "/@/components/BasicDescriptions";

export const PURCHASE_STATUS = [
  {
    value: "0",
    label: "未对账"
  },
  {
    value: "1",
    label: "对账"
  }
];

export const PURCHASE_TYPE = [
  {
    value: "1",
    label: "库存"
  },
  {
    value: "2",
    label: "非库存"
  },
  {
    value: "3",
    label: "咨询"
  }
];

export const PURCHAS_SOURCE = [
  {
    value: "1",
    label: "直接下单"
  },
  {
    value: "2",
    label: "咨询"
  },
  {
    value: "3",
    label: "项目"
  },
  {
    value: "4",
    label: "平台"
  },
  {
    value: "5",
    label: "有赞"
  }
];

export const PRODUCT_TYPE = [
  {
    value: "1",
    label: "正常商品"
  },
  {
    value: "2",
    label: "赠品"
  },
  {
    value: "3",
    label: "样品"
  }
];

export const SEND_TYPE = [
  {
    value: "1",
    label: "包邮"
  },
  {
    value: "2",
    label: "自提"
  }
];

export const PAY_STATUS = [
  {
    value: "1",
    label: "未付款"
  },
  {
    value: "2",
    label: "部分付款"
  },
  {
    value: "3",
    label: "已付款"
  }
];

export const PURCHAS_COLUMNS: DescriptionColumns = [
  {
    label: "销售订单编号",
    field: "sequenceNo",
    span: 12
  },
  // {
  //   label: "确认单编号",
  //   field: "qrdCode",
  //   span: 6
  // },
  {
    label: "采购员",
    field: "ownerName",
    span: 6,
    labelWidth: "80",
    render: (ownerName, { department }) =>
      createTooltip(ownerName, "部门: " + department, 260)
  },
  {
    label: "采购时间",
    span: 6,
    field: "createdTime"
  },
  {
    label: "买入方公司",
    field: "companyName",
    span: 12,
    render: (companyName, { companyNo }) =>
      createTooltip(companyName, "业务企业公司编号 : " + companyNo, 300)
  },
  {
    label: "卖出方公司",
    span: 12,
    field: "supplierName",
    render: (supplierName, { supplierNo }) =>
      createTooltip(supplierName, "供应商编号 : " + supplierNo, 300)
  },
  {
    label: "商品名称",
    field: "goodName",
    span: 24,
    render: (goodName, { goodNo }) =>
      createTooltip(goodName, "商品编号 : " + goodNo, 260)
  },
  {
    label: "对账状态",
    field: "status",
    render(type) {
      return h(ElTag, null, {
        default: () => PURCHASE_STATUS.find(c => c.value == type)?.label
      });
    }
  },
  {
    label: "订单来源",
    field: "cgdSource",
    render(type) {
      return h(ElTag, null, {
        default: () => cg_order_source_options.find(c => c.value == type)?.label
      });
    }
  },
  {
    label: "商品类型",
    field: "goodType",
    render(type) {
      return h(ElTag, null, {
        default: () => cg_order_type_options.find(c => c.value == type)?.label
      });
    }
  },
  {
    label: "发货状态",
    field: "sendStatus",
    render(type) {
      return h(ElTag, null, {
        default: () => send_status_list.find(c => c.value == type)?.label
      });
    }
  },

  {
    label: "商品数量",
    field: "goodNum"
  },
  {
    label: "已发货数量",
    field: "sendNum"
  },
  {
    label: "未发货数量",
    field: "wsendNum"
  },
  {
    label: "退货数量",
    field: "thNum"
  },
  // {
  //   label: "备库编号",
  //   field: "bkCode"
  // },
  // {
  //   label: "备库人员",
  //   field: "bkCreater"
  // },
  // {
  //   label: "发货方式",
  //   field: "sendType",
  //   render(sendType) {
  //     return h(ElTag, null, {
  //       default: () => cgd_send_type.find(c => c.value == sendType + "")?.label
  //     });
  //   }
  // },

  {
    label: "分类",
    span: 12,
    field: "cat",
    render(_, { firstCat, secCat, thirdCat }) {
      return h(ElTag, null, {
        default: () => firstCat + "_" + secCat + "_" + thirdCat
      });
    }
  },

  {
    label: "品牌",
    span: 8,
    field: "goodBrand"
  },

  {
    label: "核算码",
    field: "fundCode",
    span: 4
  },
  {
    label: "单位",
    field: "goodUnit"
  },
  {
    label: "税率",
    field: "tax"
  },
  {
    label: "单价",
    field: "goodPrice"
  },

  {
    label: "总价",
    field: "totalPrice"
  },
  {
    label: "已付金额",
    field: "apay_fee"
  },
  {
    label: "未付金额",
    field: "wpay_fee"
  },
  {
    label: "已回票",
    field: "ainv_fee"
  },
  {
    label: "未回票",
    field: "winv_fee"
  },
  {
    label: "工艺描述",
    span: 24,
    field: "goodDesc"
  },
  {
    label: "备注",
    span: 24,
    field: "remark"
  }
];

//商品详情
export const PURCHAS_PRODUCT_COLUMNS = [];

export const purchaseOrderColumns = [
  ...PURCHAS_COLUMNS,
  ...PURCHAS_PRODUCT_COLUMNS
];
