import { ContentConfig } from "/@/components/PageContent";
import { httpList, httpDelete } from "/@/api/purchase/ticketReturnRelive";

import dayjs from "dayjs";
import { h } from "vue";
import { ElImage, ElTag } from "element-plus";
import { checkTypeOptions, invTypeOptions, statusOptions } from "./_opitons";

const columns = [
  {
    type: "selection",
    width: 55,
    hide: ({ checkList }) => !checkList.includes("勾选列")
  },
  {
    label: "序号",
    type: "index",
    width: 70,
    hide: ({ checkList }) => !checkList.includes("序号列")
  },
  {
    label: "退票申请编号",
    prop: "returnCode",
    width: 180
  },
  {
    label: "对账编号",
    prop: "payNo",
    width: 180
  },
  {
    label: "卖方公司名称",
    prop: "supplierName"
  },
  {
    label: "卖方公司编号",
    prop: "supplierNo"
  },
  {
    label: "买方公司名称",
    prop: "companyName"
  },
  {
    label: "买方公司编号",
    prop: "companyNo"
  },
  {
    label: "状态",
    prop: "status",
    width: 160,
    transform: status =>
      statusOptions.find(s => String(status) === s.value)?.label,
    cellRenderer: ({ row, props }) =>
      h(
        ElTag,
        {
          size: props.size
        },
        {
          default: () =>
            statusOptions.find(s => String(row.status) === s.value)?.label
        }
      )
  },
  {
    label: "退票理由",
    prop: "reason"
  },
  {
    label: "申请人",
    prop: "apply_name"
  },
  {
    label: "创建时间",
    prop: "addtime",
    width: 180,
    formatter: ({ addtime }) => dayjs(addtime).format("YYYY-MM-DD HH:mm:ss")
  },
  {
    label: "操作",
    fixed: "right",
    slot: "operation",
    width: 110
  }
];

const contentConfig: ContentConfig = {
  title: "采购回票",
  statusProp: "companyNo",
  columns,
  apis: {
    httpList,
    httpDelete,
    httpAdd: true
  },
  deleteProp: "hpNo",
  superUserNoAction: true,
  delTooltip: "是否撤回采购回票申请",
  companyProp: "supplierNo",
  showDelete: ({ status }) => Number(status) !== 6
};

export default contentConfig;
